@@ -15,12 +15,11 @@
 #  limitations under the License.
 #
 
-from pycompss_cli.core import utils
 from pycompss_cli.core.arguments import parse_sys_argv
 from pycompss_cli.core.actions_dispatcher import ActionsDispatcher
+import sys
 
 # Globals
-DEBUG = False
 LINE_LENGTH = 79
 LINE = "-" * LINE_LENGTH
 
@@ -28,11 +27,11 @@ LINE = "-" * LINE_LENGTH
 def main():
     """
     MAIN ENTRY POINT
-    """
+    """        
     
     arguments = parse_sys_argv()
 
-    if utils.is_debug():
+    if arguments.debug:
         print(LINE)
         
         if 'enqueue_args' in arguments:
@@ -43,7 +42,7 @@ def main():
         print()
         print("Arguments: " + str(arguments))
 
-    ActionsDispatcher().run_action(arguments, DEBUG)
+    ActionsDispatcher().run_action(arguments)
 
 
 if __name__ == "__main__":
