@@ -44,8 +44,12 @@ class DockerActions(Actions):
         if self.arguments.working_dir == 'current directory':
             self.arguments.working_dir = os.getcwd()
 
+        if self.arguments.log_dir == 'current directory':
+            self.arguments.log_dir = os.getcwd()
+
         try:
             self.docker_cmd.docker_deploy_compss(self.arguments.working_dir,
+                                self.arguments.log_dir,
                                 self.arguments.image,
                                 self.arguments.restart,
                                 self.arguments.privileged)
@@ -95,11 +99,6 @@ class DockerActions(Actions):
         :param debug: Debug mode
         :returns: None
         """
-        if self.debug:
-            print("Running...")
-            print("Parameters:")
-            print("\t- Application: " + self.arguments.application)
-            print("\t- self.Arguments: " + str(self.arguments.argument))
 
         app_args = self.arguments.rest_args
 
@@ -114,8 +113,15 @@ class DockerActions(Actions):
 
         command = "runcompss " + ' '.join(app_args)
 
+        if self.debug:
+            print("Running...")
+            print("\t- Docker command: ", command)
+
         self.docker_cmd.docker_exec_in_daemon(command)
 
+        if 'log_dir' in self.env_conf and \
+            self.env_conf['log_dir'] == self.env_conf['working_dir']:
+            return
         self.docker_cmd.docker_exec_in_daemon('cp -a /home/user/.COMPSs/. /root/.COMPSs/')
 
 
@@ -161,8 +167,12 @@ class DockerActions(Actions):
                 f"--ip={self.env_conf['master_ip']} " + \
                 "--allow-root " + \
                 "--NotebookApp.token="
-        for out_line in self.docker_cmd.docker_exec_in_daemon(jupyter_cmd, return_stream=True):
-            print(out_line.decode().strip().replace(self.env_conf['master_ip'], 'localhost'))
+
+        try:
+            for out_line in self.docker_cmd.docker_exec_in_daemon(jupyter_cmd, return_stream=True):
+                print(out_line.decode().strip().replace(self.env_conf['master_ip'], 'localhost'), flush=True)
+        except KeyboardInterrupt:
+            print('Closing jupyter server...')
 
         if self.docker_cmd.exists():
             self.docker_cmd.docker_exec_in_daemon('pkill jupyter')
@@ -181,6 +191,15 @@ class DockerActions(Actions):
         command = "compss_gengraph " + dot_path
         self.docker_cmd.docker_exec_in_daemon(command)
 
+
+    def gentrace(self):
+        command = f"compss_gentrace {self.arguments.trace_dir} "
+        command += ' '.join(self.arguments.rest_args)
+        self.docker_cmd.docker_exec_in_daemon(command)
+        if self.arguments.download_dir:
+            self.docker_cmd.docker_exec_in_daemon(f'cp {self.arguments.trace_dir}/* {self.arguments.download_dir}/')
+
+
     def app(self):
         print("ERROR: Wrong Environment! Try using a `remote` or `local` environment")
         exit(1)
@@ -213,7 +232,7 @@ class DockerActions(Actions):
                             self.arguments.worker)
 
     def env_remove(self, env_id=None):
-        if self.docker_cmd.exists():
+        if self.docker_cmd.exists(self.env_conf['name']):
             self.docker_cmd.docker_exec_in_daemon('rm -rf .COMPSs')
             self.docker_cmd.docker_kill_compss()
         super().env_remove(eid=env_id)
