@@ -14,6 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 #
+import io
 import json
 import os
 import sys
@@ -40,13 +41,14 @@ default_image_file = "image"
 default_image = default_workdir + default_image_file
 
 
-IMAGE_NAME = "compss/compss:2.10"  # Update when releasing new version
+IMAGE_NAME = "compss/compss:3.1"  # Update when releasing new version
 DOCKER_AVAILABALE = True
 
 try:
     import docker
     from docker.types import Mount
     from docker.errors import DockerException
+    from docker.models.containers import Container
 except ImportError:
     DOCKER_AVAILABALE = False
 
@@ -59,9 +61,6 @@ class ErrorContainerNotRunning(Exception):
 
 class DockerCmd(object):
     def __init__(self, env_id) -> None:
-        global master_name
-        global worker_name
-
         self.env_id = env_id
 
         if not DOCKER_AVAILABALE:
@@ -78,9 +77,9 @@ class DockerCmd(object):
             print("       Please, start docker service and try again", file=sys.stderr)
             exit(1)
 
+        self.master_name = master_name + "-" + self.env_id
+        self.worker_name = worker_name + "-" + self.env_id
         self.__setup_image_name()
-        master_name = master_name + "-" + self.env_id
-        worker_name = worker_name + "-" + self.env_id
 
     def __setup_image_name(self):
         global IMAGE_NAME
@@ -92,16 +91,17 @@ class DockerCmd(object):
         elif os.environ.get("COMPSS_DOCKER_IMAGE") is not None:
             # If specified in an environment variable, take it
             IMAGE_NAME = os.environ["COMPSS_DOCKER_IMAGE"]
-        elif len(self.client.containers.list(filters={"name": master_name})) > 0:
+        elif len(self.client.containers.list(filters={"name": self.master_name})) > 0:
             # Condition equivalent to: is_running(master_name):
             # But since it is undefined yet, we do it explicitly.
             # If exists in the file (means that has been defined with init)
-            master = self.client.containers.list(filters={"name": master_name})[0]
+            master = self.client.containers.list(filters={"name": self.master_name})[0]
             # Command equivalent to: master = _get_master()
             # But since it is undefined yet, we do it explicitly.
             IMAGE_NAME = master.image.attrs["RepoTags"][0]
 
-    def docker_deploy_compss(self, working_dir,
+    def docker_deploy_compss(self, working_dir: str,
+                            log_dir: str,
                             image: str = "",
                             restart: bool = True,
                             privileged: bool = False) -> None:
@@ -120,27 +120,31 @@ class DockerCmd(object):
         else:
             docker_image = IMAGE_NAME
 
-        masters = self.client.containers.list(filters={"name": master_name},
+        masters = self.client.containers.list(filters={"name": self.master_name},
                                         all=True)
 
         assert len(masters) < 2  # never should we run 2 masters
 
-        if restart or self._exists(master_name):
+        if restart or self._exists(self.master_name):
             self.docker_kill_compss(False)
 
-        if not self.is_running(master_name):
-            print("Starting %s container in dir %s" % (master_name, working_dir))
+        if not self.is_running(self.master_name):
+            print("Starting %s container in dir %s" % (self.master_name, working_dir))
             print("If this is your first time running PyCOMPSs it may take a " +
                 "while because it needs to download the docker image. " +
                 "Please be patient.")
             subprocess.run(f'docker pull {docker_image}', shell=True)
-            mounts = self._get_mounts(user_working_dir=working_dir)
+            mounts = self._get_mounts(user_working_dir=working_dir, log_dir=log_dir)
             ports = {"8888/tcp": 8888,  # required for jupyter notebooks
                     "8080/tcp": 8080}  # required for monitor
-            m = self.client.containers.run(image=docker_image, name=master_name,
+            container: Container = self.client.containers.run(image=docker_image, name=self.master_name,
                                     mounts=mounts, detach=True, ports=ports, privileged=privileged)
             self._generate_resources_cfg(ips=["localhost"])
             self._generate_project_cfg(ips=["localhost"])
+
+            container.exec_run(f'mkdir -p {os.path.dirname(working_dir)}')
+            container.exec_run(f'ln -s {default_workdir} {working_dir}')
+
             # don't pass configs because they need to be  overwritten when adding
             # new nodes
             cfg_content = '{"working_dir":"' + working_dir + \
@@ -151,7 +155,7 @@ class DockerCmd(object):
 
     
     def docker_start_compss(self):
-        self.client.containers.get(master_name).start()
+        self.client.containers.get(self.master_name).start()
 
 
     def docker_update_image(self) -> None:
@@ -185,8 +189,8 @@ class DockerCmd(object):
             except ErrorContainerNotRunning:
                 print("WARNING: No master container running.")
 
-        self._stop_by_name(master_name)
-        self._stop_by_name(worker_name)
+        self._stop_by_name(self.master_name)
+        self._stop_by_name(self.worker_name)
 
 
     def docker_exec_in_daemon(self, cmd: str, return_output=False, return_stream=False) -> None:
@@ -196,7 +200,7 @@ class DockerCmd(object):
         :returns: The execution stdout.
         """
 
-        if not self.is_running(master_name):
+        if not self.is_running(self.master_name):
             self.docker_start_compss()
 
         master = self._get_master()
@@ -219,7 +223,7 @@ class DockerCmd(object):
         :returns: The monitoring initialization stdout.
         """
         print("Starting Monitor")
-        if not self.is_running(master_name):
+        if not self.is_running(self.master_name):
             self.start_daemon()
 
         cmd = "/etc/init.d/compss-monitor start"
@@ -260,8 +264,8 @@ class DockerCmd(object):
         :returns: None
         """
         if option == "list":
-            masters = self.client.containers.list(filters={"name": master_name})
-            workers = self.client.containers.list(filters={"name": worker_name})
+            masters = self.client.containers.list(filters={"name": self.master_name})
+            workers = self.client.containers.list(filters={"name": self.worker_name})
             for c in masters + workers:
                 print(c.name)
         elif option == "add":
@@ -293,12 +297,14 @@ class DockerCmd(object):
         cs = self.client.containers.list(filters={"name": name})
         return len(cs) > 0
 
-    def exists(self, name: str = master_name) -> bool:
+    def exists(self, name: str = None) -> bool:
         """ Checks if a docker instance exists.
 
         :param name: Instance name.
         :returns: True if exists. False otherwise.
         """
+        if name is None:
+            name = master_name
         cs = self.client.containers.list(all=True, filters={"name": name})
         return len(cs) > 0
 
@@ -391,7 +397,7 @@ class DockerCmd(object):
                 " OF MASTER CONTAINER!!!")
 
 
-    def _get_mounts(self, user_working_dir: str) -> list:
+    def _get_mounts(self, user_working_dir: str, log_dir: str) -> list:
         """ Retrieve the list of folders to be mounted. It gets the Mount object
         from the given user working directory, and can include any other needed
         folder.
@@ -405,13 +411,14 @@ class DockerCmd(object):
                         source=user_working_dir,
                         type="bind")
         # WARNING: mounting .COMPSs makes it fail
-        # compss_logs_dir = os.environ["HOME"] + f"/.COMPSs"
-        # os.makedirs(compss_logs_dir, exist_ok=True)
+        if '.COMPSs' not in log_dir:
+            log_dir = log_dir + "/.COMPSs"
+        os.makedirs(log_dir, exist_ok=True)
 
-        # compss_log_dir = Mount(target="/root/.COMPSs",
-        #                        source=compss_logs_dir,
-        #                        type="bind")
-        mounts = [user_dir]
+        compss_log_dir = Mount(target="/root/.COMPSs",
+                               source=log_dir,
+                               type="bind")
+        mounts = [user_dir, compss_log_dir]
         return mounts
 
 
@@ -600,3 +607,17 @@ class DockerCmd(object):
         containers = self.client.containers.list(filters={"name": name}, all=True)
         for c in containers:
             c.remove(force=True)
+
+    def docker_copy_to_host(self, container_name, src, dst):
+        """ Copy files from a container directory to a host directory.
+
+        :param container_name: Name of the container.
+        :param src: Source path.
+        :param dst: Destination path.
+        :returns: None
+        """
+        container = self.client.containers.get(container_name)
+        data, stat = container.get_archive(src)
+        with open(dst, 'wb') as f:
+            for chunk in data:
+                f.write(chunk)
