@@ -21,6 +21,7 @@ import tempfile
 from shutil import copyfile
 import subprocess
 import tempfile
+import zipfile
 import pycompss_cli.core.utils as utils
 
 # ################ #
@@ -64,7 +65,14 @@ def remote_deploy_compss(env_id: str, login_info: str, modules, envars=[]) -> No
     subprocess.run(f"scp -r {local_job_scripts_dir} '{login_info}:~/.COMPSs/'", shell=True, stdout=subprocess.PIPE)
     
 
-def remote_app_deploy(app_dir: str, login_info: str, local_source: str, remote_dest_dir: str = None):
+def remote_app_deploy(app_dir: str, login_info: str, local_source: str, remote_dest_dir: str = None, env_file: str = None):
+
+    if env_file:
+        if not os.path.isfile(env_file):
+            print(f'ERROR: env file `{env_file}` not found.')
+            exit(1)
+            
+
     print('Deploying app...')
     utils.ssh_run_commands(login_info, [f'mkdir -p {app_dir}'])
 
@@ -75,6 +83,10 @@ def remote_app_deploy(app_dir: str, login_info: str, local_source: str, remote_d
 
     subprocess.run(cmd_copy_files, shell=True)
 
+    if env_file:
+        cmd_copy_files = f"scp {env_file} {login_info}:'{app_dir}/.env'"
+        subprocess.run(cmd_copy_files, shell=True)
+
     if remote_dest_dir:
         print('App deployed to', remote_dest_dir)
         utils.ssh_run_commands(login_info, [
@@ -97,25 +109,26 @@ def remote_run_app(remote_dir: str, login_info: str, env_name: str, command: str
     ]
     return utils.ssh_run_commands(login_info, commands)[0]
 
-def remote_submit_job(login_info: str, remote_dir: str, app_args: str, modules, envars=None) -> None:
+def remote_submit_job(login_info: str, remote_dir: str, app_args: str, modules, envars=None, debug=False) -> None:
     """ Execute the given command in the remote COMPSs environment.
 
     :param cmd: Command to execute.
     :returns: The execution stdout.
     """
 
-    enqueue_debug = '-d' if utils.is_debug() else ''
+    enqueue_debug = '-d' if debug else ''
 
     commands = [
         f'cd {remote_dir}',
         *modules,
+        'if [ -f .env ]; then source .env; fi',
         f'enqueue_compss {enqueue_debug} {app_args}'
     ]
 
     if envars:
         commands = [f'export {var}' for var in envars] + commands
 
-    if utils.is_debug():
+    if debug:
         print('********* DEBUG *********')
         print('Remote submit job commands:')
         for cmd in commands:
@@ -123,7 +136,7 @@ def remote_submit_job(login_info: str, remote_dir: str, app_args: str, modules,
         print('***************************')
 
     stdout, stderr = utils.ssh_run_commands(login_info, commands)
-    if utils.is_debug():
+    if debug:
         print('Remote submit job stdout:')
         print(stdout.strip())
         print('***************************')
@@ -180,5 +193,35 @@ def remote_cancel_job(login_info: str, job_id: str, modules):
     stdout = utils.ssh_run_commands(login_info, commands)[0].strip()
     print(stdout)
 
-def remote_exec_app(login_info: str, exec_cmd: str):
+def remote_exec_app(login_info: str, exec_cmd: str, debug=False):
+    if debug:
+        print('Remote exec app command:')
+        print('\t', '->', exec_cmd)
     return utils.ssh_run_commands(login_info, [exec_cmd])[0].strip()
+
+
+def remote_download_file(login_info: str, remote_path: str, local_path: str, debug=False, compressed=False):
+    if not os.path.isdir(local_path):
+        if os.path.exists(local_path):
+            print(f'ERROR: local path `{local_path}` is not a directory.')
+            exit(1)
+        else:
+            os.makedirs(local_path)
+
+    if compressed:
+        cmd = f'scp -r {login_info}:{remote_path}/trace.zip {local_path}'
+    else:
+        cmd = f'scp -r {login_info}:{remote_path}/* {local_path}'
+
+    if debug:
+        print('Remote download file command:')
+        print('\t', cmd)
+
+    subprocess.run(cmd, shell=True)
+
+    if compressed:
+        print('Uncompressing trace...')
+        zip_path = os.path.join(local_path, 'trace.zip')
+        with zipfile.ZipFile(zip_path, 'r') as zip_ref:
+            zip_ref.extractall(local_path)
+        os.remove(zip_path)
